@@ -1,5 +1,5 @@
 use std::num::Wrapping;
-use std::ops::{Add, BitXor, BitXorAssign, Index, IndexMut};
+use std::ops::{BitXor, BitXorAssign, Index, IndexMut};
 
 #[derive(Clone, Copy, Debug)]
 pub struct ZestBlock {
@@ -32,26 +32,12 @@ impl ZestBlock {
     }
 }
 
-//Addition, u64 wise. Not meant to treat as a single large number,
-//But adding seperately each u64 element!
-impl Add<ZestBlock> for ZestBlock {
-    type Output = ZestBlock;
-    #[inline(always)]
-    fn add(self, rhs: ZestBlock) -> Self::Output {
-        let mut total = ZestBlock::new();
-        for (index, chunk) in total.data.iter_mut().enumerate() {
-            *chunk = (Wrapping(self[index]) + Wrapping(rhs[index])).0;
-        }
-        total
-    }
-}
-
 //XOR, bitwise.
 impl BitXor<ZestBlock> for ZestBlock {
     type Output = ZestBlock;
     #[inline(always)]
     fn bitxor(self, rhs: ZestBlock) -> Self::Output {
-        let mut xored = ZestBlock::new();
+        let mut xored = self;
         for (index, chunk) in xored.data.iter_mut().enumerate() {
             *chunk ^= rhs[index];
         }
